@@ -33,8 +33,7 @@ make.par.list <- function(nams, x, n, m, def, recycle = sum(unnamed) > 0) {
   lapply(y, function(y) if (length(y)==1) y else rep(y, length.out = n))
 }
 
-plot.zoo <- function(x, y = NULL, screens = 1,
-  plot.type = c("multiple", "single"), panel = lines, 
+plot.zoo <- function(x, y = NULL, screens, plot.type, panel = lines, 
   xlab = "Index", ylab = NULL, main = NULL, xlim = NULL, ylim = NULL,
   xy.labels = FALSE, xy.lines = NULL,
   oma = c(6, 0, 5, 0), mar = c(0, 5.1, 0, 2.1), 
@@ -68,9 +67,19 @@ plot.zoo <- function(x, y = NULL, screens = 1,
 
   recycle <- function(a, len, nser)
      rep(lapply(as.list(a), rep, length.out = len), length.out = nser)
-  plot.type <- match.arg(plot.type)
-  dots <- list(...)
+  # same as range except it passes pairs through
+  range2 <- function(x, ...) if (length(x) == 2) x else range(x, ...)
+  if (missing(plot.type)) {
+	plot.type <- if (missing(screens)) "multiple"
+	else if (length(unique(screens) == 1)) "single" 
+	else "multiple"
+  }
+  plot.type <- match.arg(plot.type, c("multiple", "single"))
   nser <- NCOL(x)
+  if (missing(screens)) {
+	screens <- if (plot.type == "single") 1 else seq_len(nser)
+  }	
+  dots <- list(...)
   x.index <- index(x)
   if(is.ts(x.index)) x.index <- as.vector(x.index)
   cn <- if (is.null(colnames(x))) paste("V", seq(length = nser), sep = "")
@@ -94,11 +103,11 @@ plot.zoo <- function(x, y = NULL, screens = 1,
     pch <- make.par.list(cn, pch, NROW(x), nser, par("pch"))
     type <- make.par.list(cn, type, NROW(x), nser, "l")
     if (!is.null(ylim)) {
-        if (is.list(ylim)) ylim <- lapply(ylim, range, na.rm = TRUE)
-	else ylim <- list(range(ylim, na.rm = TRUE))
+        if (is.list(ylim)) ylim <- lapply(ylim, range2, na.rm = TRUE)
+	else ylim <- list(range2(ylim, na.rm = TRUE))
 	ylim <- lapply(make.par.list(cn, ylim, 2, nser, NULL), function(x) 
-		if (is.null(x) || length(na.omit(x)) ==0) NULL 
-		else range(x, na.rm = TRUE))
+		if (is.null(x) || length(na.omit(x)) == 0) NULL 
+		else range2(x, na.rm = TRUE))
     }
     panel <- match.fun(panel)
     if(missing(nc)) nc <- if(ngraph >  4) 2 else 1
@@ -108,20 +117,22 @@ plot.zoo <- function(x, y = NULL, screens = 1,
     layout(matrix(seq(nr*nc), nr), widths = widths, heights = heights)
     par(mar = mar, oma = oma)
     ranges <- if (is.null(ylim))
-	by(1:ncol(x), screens, function(idx) range(x[,idx], na.rm = TRUE))
-        else by(1:ncol(x), screens, function(idx) 
+	tapply(1:ncol(x), screens, function(idx) range(x[,idx], na.rm = TRUE))
+        else tapply(1:ncol(x), screens, function(idx) 
 		if (is.null(ylim[[idx]])) range(x[,idx], na.rm = TRUE)
 		else ylim[[idx]])
     for(j in seq(along = levels(screens))) {
       panel.number <- j
       range. <- rep(ranges[[j]], length.out = length(time(x)))
       if(j%%nr==0 || j == length(levels(screens))) {
-	args <- list(x.index, range., xlab = "", ylab = ylab[j], xlim = xlim, ...)
+	args <- list(x.index, range., xlab = "", ylab = ylab[j], 
+		xlim = xlim, ylim = ylim[[j]], ...)
 	args$type <- "n"
 	do.call("plot", args)
 	mtext(xlab, side = 1, line = 3)
       } else {      
-        args <- list(x.index, range., axes = FALSE, xlab = "", ylab = ylab[j], xlim = xlim, ...)
+        args <- list(x.index, range., axes = FALSE, xlab = "", ylab = ylab[j], 
+		xlim = xlim, ylim = ylim[[j]], ...)
 	args$type <- "n"
 	do.call("plot", args)
         box()
@@ -136,7 +147,7 @@ plot.zoo <- function(x, y = NULL, screens = 1,
     if(is.null(main)) main <- ""
     main.outer <- FALSE
     if(is.null(ylim)) ylim <- range(x, na.rm = TRUE)
-	else ylim <- range(c(ylim, recursive = TRUE), na.rm = TRUE)
+	else ylim <- range2(c(ylim, recursive = TRUE), na.rm = TRUE)
 
     lty <- rep(lty, length.out = nser)
     col <- make.par.list(cn, col, NROW(x), nser, 1)
